@@ -148,6 +148,51 @@ def test_factory_wateroil():
     assert "pc" not in wateroil.table
 
 
+def test_fast_mode():
+    """Test that the fast-flag is passed on to constructed objects
+
+    Each object's own test code tests the actual effects of the fast flag"""
+    wateroil = PyscalFactory.create_water_oil({"nw": 2, "now": 2})
+    assert not wateroil.fast
+    wateroil = PyscalFactory.create_water_oil({"nw": 2, "now": 2}, fast=True)
+    assert wateroil.fast
+
+    gasoil = PyscalFactory.create_gas_oil({"ng": 2, "nog": 2})
+    assert not gasoil.fast
+    gasoil = PyscalFactory.create_gas_oil({"ng": 2, "nog": 2}, fast=True)
+    assert gasoil.fast
+
+    gaswater = PyscalFactory.create_gas_water({"nw": 2, "ng": 2})
+    assert not gaswater.gasoil.fast
+    assert not gaswater.wateroil.fast
+    gaswater = PyscalFactory.create_gas_water({"nw": 2, "ng": 2}, fast=True)
+    assert gaswater.gasoil.fast
+    assert gaswater.wateroil.fast
+    assert gaswater.fast
+
+    wateroilgas = PyscalFactory.create_water_oil_gas(
+        {"nw": 2, "now": 2, "ng": 2, "nog": 2}, fast=True
+    )
+    assert wateroilgas.fast
+    assert wateroilgas.wateroil.fast
+    assert wateroilgas.gasoil.fast
+
+    scalrec = PyscalFactory.create_scal_recommendation(
+        {
+            "low": {"nw": 2, "now": 2, "ng": 2, "nog": 2},
+            "base": {"nw": 2, "now": 2, "ng": 2, "nog": 2},
+            "high": {"nw": 2, "now": 2, "ng": 2, "nog": 2},
+        },
+        fast=True,
+    )
+    assert scalrec.low.fast
+    assert scalrec.base.fast
+    assert scalrec.high.fast
+
+    interpolant = scalrec.interpolate(-0.5)
+    assert interpolant.fast
+
+
 def test_init_with_swlheight():
     """With sufficient parameters, swl will be calculated on the fly
     when initializing the WaterOil object"""
@@ -900,6 +945,40 @@ def test_case_aliasing():
         )
 
 
+def test_swirr_partially_missing(tmpdir):
+    """Test that swirr can be present for only a subset of the rows,
+    and interpreted as zero when not there."""
+    dframe = pd.DataFrame(
+        columns=[
+            "SATNUM",
+            "Nw",
+            "Now",
+            "swl",
+            "swirr",
+            "a",
+            "b",
+            "poro_ref",
+            "perm_ref",
+            "drho",
+        ],
+        data=[
+            [1, 2, 2, 0.2, 0.1, 2, -2, 0.2, 100, 300],
+            [2, 3, 3, 0.1, np.nan, np.nan, np.nan, np.nan, np.nan],
+        ],
+    )
+    relperm_data = PyscalFactory.load_relperm_df(dframe)
+    p_list = PyscalFactory.create_pyscal_list(relperm_data, h=0.2)
+    assert "a=2, b=-2" in p_list[1].pccomment
+    assert p_list[2].pccomment == ""
+
+    tmpdir.chdir()
+    dframe.to_excel("partial_pc.xlsx")
+    relperm_data_via_xlsx = PyscalFactory.load_relperm_df("partial_pc.xlsx")
+    p_list = PyscalFactory.create_pyscal_list(relperm_data_via_xlsx, h=0.2)
+    assert "a=2, b=-2" in p_list[1].pccomment
+    assert p_list[2].pccomment == ""
+
+
 def test_corey_let_mix():
     """Test that we can supply a dataframe where some SATNUMs
     have Corey and others have LET"""
@@ -945,8 +1024,17 @@ def test_infer_tabular_file_format(tmpdir, caplog):
     # Ensure factory.py's error message got through:
     assert "Impossible to infer file format for empty.csv" in caplog.text
 
-    # Write 10 random bytes to a file, this should with very
+    # We don't want ISO-8859 files, ensure we fail
+    norw_chars = "Dette,er,en,CSV,fil\nmed,iso-8859:,æ,ø,å"
+    Path("iso8859.csv").write_bytes(norw_chars.encode("iso-8859-1"))
+    assert factory.infer_tabular_file_format("iso8859.csv") == ""
+    # Providing an error that this error was due to ISO-8859 and
+    # nothing else is deemed too hard.
+    Path("utf8.csv").write_bytes(norw_chars.encode("utf-8"))
+    assert factory.infer_tabular_file_format("utf8.csv") == "csv"
+
+    # Write some random bytes to a file, this should with very
     # little probability give a valid xlsx/xls/csv file.
-    Path("wrong.csv").write_bytes(os.urandom(10))
+    Path("wrong.csv").write_bytes(os.urandom(100))
     assert factory.infer_tabular_file_format("wrong.csv") == ""
     assert "Impossible to infer file format for wrong.csv" in caplog.text
