@@ -1,14 +1,9 @@
 """Test the pyscal client"""
-# -*- encoding: utf-8 -*-
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-import os
 import sys
 import subprocess
 import logging
+from pathlib import Path
 
 import pandas as pd
 
@@ -26,73 +21,56 @@ def test_installed():
     assert subprocess.check_output(["pyscal", "-h"])
     assert subprocess.check_output(["pyscal", "--help"])
 
-    # On Py2, the version output is sent to stderr:
-    assert subprocess.check_output(["pyscal", "--version"], stderr=subprocess.STDOUT)
+    assert subprocess.check_output(["pyscal", "--version"])
 
 
-def test_log_levels(tmpdir, caplog):
+@pytest.mark.skipif(sys.version_info < (3, 7), reason="Requires Python 3.7 or higher")
+@pytest.mark.parametrize("verbosity_flag", [None, "--verbose", "--debug"])
+def test_log_levels(tmpdir, verbosity_flag):
     """Test that we can control the log level from the command line
     client, and get log output from modules deep down"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
 
-    relperm_file = testdir + "/data/relperm-input-example.xlsx"
-
-    tmpdir.chdir()
-
-    caplog.clear()
-    sys.argv = ["pyscal", relperm_file]
-    pyscalcli.main()
-
-    # Ensure we have no INFO logging:
-    assert not any(record.levelno == logging.INFO for record in caplog.records)
-
-    # The following is an INFO statement from factory.py that we should not get:
-    assert all("Loaded input data" not in str(record) for record in caplog.records)
-    # And a debug statement from gasoil.py
-    assert all(
-        "Added Corey gas to GasOil object" not in str(record)
-        for record in caplog.records
+    relperm_file = str(
+        Path(__file__).absolute().parent / "data" / "relperm-input-example.xlsx"
     )
 
-    caplog.clear()
-    sys.argv = ["pyscal", "--verbose", relperm_file]
-    pyscalcli.main()
-    assert not any(record.levelno == logging.DEBUG for record in caplog.records)
-    assert any(record.levelno == logging.INFO for record in caplog.records)
-    assert not any(record.levelno == logging.ERROR for record in caplog.records)
-    assert any("Loaded input data" in str(record) for record in caplog.records)
-    assert any("Dumping" in str(record) for record in caplog.records)
+    commands = ["pyscal", relperm_file]
+    if verbosity_flag is not None:
+        commands.append(verbosity_flag)
 
-    caplog.clear()
-    sys.argv = ["pyscal", "--debug", relperm_file]
-    pyscalcli.main()
-    assert any(record.levelno == logging.DEBUG for record in caplog.records)
-    assert any("Initialized GasOil with" in str(record) for record in caplog.records)
-    assert any("Initialized WaterOil with" in str(record) for record in caplog.records)
+    result = subprocess.run(commands, cwd=tmpdir, capture_output=True, check=True)
+    output = result.stdout.decode() + result.stderr.decode()
+
+    if verbosity_flag is None:
+        assert "INFO:" not in output
+        assert "DEBUG:" not in output
+    elif verbosity_flag == "--verbose":
+        assert "INFO:" in output
+        assert "DEBUG:" not in output
+        assert "Loaded input data" in output
+        assert "Dumping" in output
+    elif verbosity_flag == "--debug":
+        assert "INFO:" in output
+        assert "DEBUG:" in output
+        assert "Initialized GasOil with" in output
+        assert "Initialized WaterOil with" in output
+    else:
+        raise ValueError("Unknown value for 'verbosity_flag'")
 
 
 def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     # pylint: disable=unused-argument
     # default_loglevel fixture is in conftest.py
     """Test pyscal client for static relperm input"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
-
-    relperm_file = testdir + "/data/relperm-input-example.xlsx"
+    testdir = Path(__file__).absolute().parent
+    relperm_file = testdir / "data/relperm-input-example.xlsx"
 
     tmpdir.chdir()
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file]
+    sys.argv = ["pyscal", str(relperm_file)]
     pyscalcli.main()
-    assert os.path.exists("relperm.inc")
+    assert Path("relperm.inc").is_file()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
     assert not any(record.levelno == logging.INFO for record in caplog.records)
 
@@ -107,22 +85,22 @@ def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     sat_table_str_ok(relpermlines)
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "--output", "alt2relperm.inc"]
+    sys.argv = ["pyscal", str(relperm_file), "--output", "alt2relperm.inc"]
     pyscalcli.main()
-    assert os.path.exists("alt2relperm.inc")
+    assert Path("alt2relperm.inc").is_file()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "-o", "altrelperm.inc"]
+    sys.argv = ["pyscal", str(relperm_file), "-o", "altrelperm.inc"]
     pyscalcli.main()
-    assert os.path.exists("altrelperm.inc")
+    assert Path("altrelperm.inc").is_file()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "--family2", "-o", "relperm-fam2.inc"]
+    sys.argv = ["pyscal", str(relperm_file), "--family2", "-o", "relperm-fam2.inc"]
     pyscalcli.main()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
-    assert os.path.exists("relperm-fam2.inc")
+    assert Path("relperm-fam2.inc").is_file()
     relpermlines = "\n".join(open("relperm-fam2.inc").readlines())
     assert "SWFN" in relpermlines
     assert "SGFN" in relpermlines
@@ -132,10 +110,10 @@ def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     sat_table_str_ok(relpermlines)
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "--slgof", "--output", "relperm-slgof.inc"]
+    sys.argv = ["pyscal", str(relperm_file), "--slgof", "--output", "relperm-slgof.inc"]
     pyscalcli.main()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
-    assert os.path.exists("relperm-slgof.inc")
+    assert Path("relperm-slgof.inc").is_file()
     relpermlines = "\n".join(open("relperm-slgof.inc").readlines())
     assert "SWOF" in relpermlines
     assert "SGOF" not in relpermlines
@@ -147,26 +125,26 @@ def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     # Dump to deep directory structure that does not exists
     sys.argv = [
         "pyscal",
-        relperm_file,
+        str(relperm_file),
         "--family2",
         "-o",
         "eclipse/include/props/relperm-fam2.inc",
     ]
     pyscalcli.main()
-    assert os.path.exists("eclipse/include/props/relperm-fam2.inc")
+    assert Path("eclipse/include/props/relperm-fam2.inc").is_file()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "-o", "include/props/relperm.inc"]
+    sys.argv = ["pyscal", str(relperm_file), "-o", "include/props/relperm.inc"]
     pyscalcli.main()
-    assert os.path.exists("include/props/relperm.inc")
+    assert Path("include/props/relperm.inc").is_file()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
 
     caplog.clear()
     # Check that we can read specific sheets
     sys.argv = [
         "pyscal",
-        relperm_file,
+        str(relperm_file),
         "--sheet_name",
         "relperm",
         "--output",
@@ -184,7 +162,7 @@ def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     caplog.clear()
     sys.argv = [
         "pyscal",
-        relperm_file,
+        str(relperm_file),
         "--sheet_name",
         "simple",
         "--output",
@@ -201,7 +179,7 @@ def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     caplog.clear()
     sys.argv = [
         "pyscal",
-        relperm_file,
+        str(relperm_file),
         "--sheet_name",
         u"NOTEXISTINGÆÅ",
         "--output",
@@ -209,16 +187,23 @@ def test_pyscal_client_static(tmpdir, caplog, default_loglevel):
     ]
     with pytest.raises(SystemExit):
         pyscalcli.main()
-    assert not os.path.exists("relperm-empty.inc")
+    assert not Path("relperm-empty.inc").is_file()
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "--delta_s", "0.1", "-o", "deltas0p1.inc"]
+    sys.argv = ["pyscal", str(relperm_file), "--delta_s", "0.1", "-o", "deltas0p1.inc"]
     pyscalcli.main()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
     linecount1 = len(open("deltas0p1.inc").readlines())
 
     caplog.clear()
-    sys.argv = ["pyscal", relperm_file, "--delta_s", "0.01", "-o", "deltas0p01.inc"]
+    sys.argv = [
+        "pyscal",
+        str(relperm_file),
+        "--delta_s",
+        "0.01",
+        "-o",
+        "deltas0p01.inc",
+    ]
     pyscalcli.main()
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
     linecount2 = len(open("deltas0p01.inc").readlines())
@@ -338,22 +323,16 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
     # pylint: disable=unused-argument
     # default_loglevel fixture is in conftest.py
     """Test the command line endpoint on SCAL recommendation"""
-    if "__file__" in globals():
-        # Easen up copying test code into interactive sessions
-        testdir = os.path.dirname(os.path.abspath(__file__))
-    else:
-        testdir = os.path.abspath(".")
-
-    scalrec_file = testdir + "/data/scal-pc-input-example.xlsx"
+    scalrec_file = Path(__file__).absolute().parent / "data/scal-pc-input-example.xlsx"
 
     tmpdir.chdir()
 
-    sys.argv = ["pyscal", scalrec_file]
+    sys.argv = ["pyscal", str(scalrec_file)]
     with pytest.raises(SystemExit):
         pyscalcli.main()
 
     caplog.clear()
-    sys.argv = ["pyscal", scalrec_file, "--int_param_wo", 0, "-o", "relperm1.inc"]
+    sys.argv = ["pyscal", str(scalrec_file), "--int_param_wo", 0, "-o", "relperm1.inc"]
     pyscalcli.main()
     assert not any(record.levelno == logging.INFO for record in caplog.records)
     assert not any(record.levelno == logging.WARNING for record in caplog.records)
@@ -368,7 +347,14 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
     # assert "int_param_wo: 0\n" in relpermlines  # this should be in the tag.
 
     caplog.clear()
-    sys.argv = ["pyscal", scalrec_file, "--int_param_wo", "-0.5", "-o", "relperm2.inc"]
+    sys.argv = [
+        "pyscal",
+        str(scalrec_file),
+        "--int_param_wo",
+        "-0.5",
+        "-o",
+        "relperm2.inc",
+    ]
     pyscalcli.main()
     assert not any(record.levelno == logging.INFO for record in caplog.records)
     assert not any(record.levelno == logging.WARNING for record in caplog.records)
@@ -376,14 +362,14 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
     # assert something about -0.5 in the comments
 
     # Only two interpolation parameters for three satnums:
-    sys.argv = ["pyscal", scalrec_file, "--int_param_wo", "-0.5", "0"]
+    sys.argv = ["pyscal", str(scalrec_file), "--int_param_wo", "-0.5", "0"]
     with pytest.raises(SystemExit):
         pyscalcli.main()
 
     caplog.clear()
     sys.argv = [
         "pyscal",
-        scalrec_file,
+        str(scalrec_file),
         "--int_param_wo",
         "-0.5",
         "0.0",
@@ -395,12 +381,12 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
     assert not any(record.levelno == logging.INFO for record in caplog.records)
     assert not any(record.levelno == logging.WARNING for record in caplog.records)
     assert not any(record.levelno == logging.ERROR for record in caplog.records)
-    assert os.path.exists("relperm3.inc")
+    assert Path("relperm3.inc").is_file()
     # assert someting about three different parameters..
 
     sys.argv = [
         "pyscal",
-        scalrec_file,
+        str(scalrec_file),
         "--int_param_wo",
         "-0.5",
         "0",
@@ -411,11 +397,11 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
         "relperm4.inc",
     ]
     pyscalcli.main()
-    assert os.path.exists("relperm4.inc")
+    assert Path("relperm4.inc").is_file()
 
     sys.argv = [
         "pyscal",
-        scalrec_file,
+        str(scalrec_file),
         "--int_param_wo",
         "-0.5",
         "0",
@@ -428,7 +414,7 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
         pyscalcli.main()
     sys.argv = [
         "pyscal",
-        scalrec_file,
+        str(scalrec_file),
         "--int_param_wo",
         "-0.5",
         "0",
@@ -441,5 +427,5 @@ def test_pyscal_client_scal(tmpdir, caplog, default_loglevel):
         "relperm5.inc",
     ]
     pyscalcli.main()
-    assert os.path.exists("relperm5.inc")
+    assert Path("relperm5.inc").is_file()
     # check that interpolation parameters have been used.
